..
    This file is part of Invenio.
    Copyright (C) 2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Contributors
============

- Achintya Rao
- Adam Lawrence
- Alizee Pace
- Diego Rodriguez
- Esteban J. G. Gabancho
- Guillaume Lastecoueres
- Ivan Masár
- Javier Delgado
- Jiri Kuncar
- João Gonçalves
- Lars Holm Nielsen
- Leonardo Rossi
- Nicola Tarocco
- Nicolas Harraudeau
- Rémi Ducceschi
- Sami Hiltunen
- Samuele Kaplun
- Tibor Simko
- Xiao Meng
